|	basic_words.g - provides ~34 basic words for Greg's forth perversion
|	Greg Alexander - 99/8/6

|	start - the starting point for all programs -- calls main
:start
"	move.l	#callstktop,SP	| setup calling stack
"	move.l	#datastktop,A6	| setup data stack
.main				| call main program start
>exit				| return to monitor

".globl	callstktop,datastktop
"callstk:	.=.+ 1024	| allocate space for our stacks
"callstktop:
"datastk:	.=.+ 1024
"datastktop:


|	exit - ( -- )
|	returns to the monitor
:exit
"	trap	#15
"	.word	0


|	at - ( val adr -- )
|	writes val to adr (4-bytes)
:at
"	movea.l	(A6)+,A0
"	move.l	(A6)+,(A0)
	;


|	atw - ( val adr -- )
|	writes val to adr (2-bytes)
:atw
"	movea.l	(A6)+,A0
"	move.l	(A6),D0
"	move.w	D0,(A0)
"	addq.l	#4,A6
	;


|	atb - ( val adr -- )
|	writes val to adr (1-byte)
:atb
"	movea.l	(A6)+,A0
"	move.l	(A6),D0
"	move.b	D0,(A0)
"	addq.l	#4,A6
	;


|	bang - ( adr -- val )
|	reads val from adr (4-bytes)
:bang
"	movea.l	(A6),A0
"	move.l	(A0),(A6)
	;


|	bangw - ( adr -- val )
|	reads val from adr (2-bytes)
:bangw
"	movea.l	(A6),A0
"	clr.l	D0
"	move.w	(A0),D0
"	move.l	D0,(A6)
	;


|	bangb - ( adr -- val )
|	reads val from adr (1-byte)
:bangb
"	movea.l	(A6),A0
"	clr.l	D0
"	move.b	(A0),D0
"	move.l	D0,(A6)
	;


|	add - ( x y -- x+y )
|	adds x and y
:add
"	move.l	(A6)+,D0
"	add.l	(A6),D0
"	move.l	D0,(A6)
	;


|	sub - ( x y -- x-y )
|	subtracts y from x
:sub
"	move.l	4(A6),D0
"	sub.l	(A6)+,D0
"	move.l	D0,(A6)
	;


|	times - ( x y -- x*y )
|	unsigned multiplies x and y
:times
"	move.l	(A6)+,D0
"	mulu.l	(A6),D0
"	move.l	D0,(A6)
	;


|	inc - ( adr -- )
|	increments the cell at adr
:inc
"	movea.l	(A6)+,A0
"	addq.l	#1,(A0)
	;


|	dec - ( adr -- )
|	decrements the cell at adr
:dec
"	movea.l	(A6)+,A0
"	subq.l	#1,(A0)
	;


|	toggle - ( adr -- )
|	toggles the boolean in the cell at adr
:toggle
"	movea.l	(A6)+,A0
"	tst.l	(A0)
"	beq	toggle_true
"	clr.l	(A0)
"	rts
"toggle_true:
"	move.l	#0xffffffff,(A0)
	;



|	lsr - ( x n -- x>>n )
|	shifts x right by n bytes
:lsr
"	move.l	(A6)+,D0
"	move.l	(A6),D1
"	lsr.l	D0,D1
"	move.l	D1,(A6)
	;


|	andb - ( x y -- x&y )
|	binary and of x and y
:andb
"	move.l	(A6)+,D0
"	and.l	D0,(A6)
	;


|	orb - ( x y -- x&y )
|	binary or of x and y
:orb
"	move.l	(A6)+,D0
"	or.l	D0,(A6)
	;


|	memset - ( s c n -- )
|	copies the lower byte from c into the n memory locations
|	starting at s -- always copies at least one byte!
:memset
"	move.l	(A6)+,D1	| D1=n
"	move.l	(A6)+,D0	| D0=c
"	movea.l	(A6)+,A0	| A0=s (starting point)
"	movea.l	A0,A1
"	adda.l	D1,A1		| now A1=ending point
"memset_loop:
"	move.b	D0,(A0)+
"	cmpa.l	A0,A1
"	bgt	memset_loop
	;


|	memcpy - (s1 s2 n -- )
|	copies n bytes from s1 to s2 -- always copies at least one byte!
:memcpy
"	move.l	(A6)+,D0	| D0=n
"	move.l	(A6)+,A1	| A1=s2
"	move.l	(A6)+,A0	| A0=s1
"	movea.l	A0,A2
"	adda.l	D0,A2		| A2=ending point for s1 (A0<A2)
"memcpy_loop:
"	move.b	(A0)+,(A1)+
"	cmpa.l	A0,A2
"	bgt	memcpy_loop
	;


|	ifte - ( flag then else -- )
|	calls then if flag is non-zero, else if flag is 0
|	instead of having "call foo\nret", we do "jmp foo" -- yay tail
|	recursive optimization!! :)
:ifte
"	tst.l	8(A6)		| check flag
"	bne	ifte_then
"	movea.l	(A6)+,A0	| load the else addr into A0
"	addq.l	#8,A6
"	jmp	(A0)
"ifte_then:			| flag was 0
"	movea.l	4(A6),A0	| load the then addr into A0
"	add.l	#12,A6
"	jmp	(A0)


|	ift - (flag then -- )
|	just like ifte, but no else case
:ift
"	tst.l	4(A6)		| check flag
"	beq	ift_else
"	movea.l	(A6),A0		| load the then addr into A0
"	addq.l	#8,A6
"	jmp	(A0)
"ift_else:			| flag was 0
"	addq.l	#8,A6
	;


|	cmp_true - ( x -- TRUE )
|	replaces the top entry with TRUE, only really useful for the
|	boolean ops in this module
'cmp_true
"	move.l	#0xffffffff,(A6)
	;


|	cmp_false - ( x -- FALSE )
|	replaces the top entry with FALSE, only really useful for the
|	boolean ops in this module
'cmp_false
"	clr.l	(A6)
	;


|	not - ( x -- !x )
|	this is a boolean not
:not
"	tst.l	(A6)
"	beq	cmp_true
"	clr.l	(A6)
	;


|	eq - ( x y -- x==y )
|	pushes a boolean for x equal-to y
:eq
"	move.l	(A6)+,D0
"	cmp.l	(A6),D0		| cmp.l x,y
"	beq	cmp_true
"	clr.l	(A6)
	;


|	gt - ( x y -- x>y )
|	pushes a boolean for x greater-than y
:gt
"	move.l	(A6)+,D0
"	cmp.l	(A6),D0		| cmp.l x,y
"	blt	cmp_true
"	clr.l	(A6)
	;


|	lt - ( x y -- x<y )
|	pushes a boolean for x less-than y
:lt
"	move.l	(A6)+,D0
"	cmp.l	(A6),D0		| cmp.l x,y
"	bgt	cmp_true
"	clr.l	(A6)
	;


|	and - ( x y -- x&&y )
|	boolean and
:and
"	tst.l	(A6)+
"	beq	cmp_false
"	tst.l	(A6)
"	beq	cmp_false
"	move.l	#0xffffffff,(A6)
	;


|	or - ( x y -- x||y )
|	boolean or
:or
"	tst.l	(A6)+
"	bne	cmp_true
"	tst.l	(A6)
"	bne	cmp_true
"	clr.l	(A6)
	;



|	popular forth stack manipulation words

|	dup - ( x -- x x )
|	duplicates the top item on the stack
:dup
"	move.l	(A6),-(A6)
	;


|	dup2 - ( x y -- x y x y )
|	duplicates the top two items on the stack
:dup2
"	move.l	4(A6),-(A6)
"	move.l	4(A6),-(A6)
	;


|	dup3 - ( x y z -- x y z x y z )
|	duplicates the top three items on the stack
:dup3
"	move.l	8(A6),-(A6)
"	move.l	8(A6),-(A6)
"	move.l	8(A6),-(A6)
	;


|	dup4 - ( x y z a -- x y z a x y z a )
|	duplicates the top four items on the stack
:dup4
"	move.l	12(A6),-(A6)
"	move.l	12(A6),-(A6)
"	move.l	12(A6),-(A6)
"	move.l	12(A6),-(A6)
	;


|	over - ( x y -- x y x )
|	duplicates the second item down on the stack, onto the top
:over
"	move.l	4(A6),-(A6)
	;


|	over3 - ( x y z -- x y z x )
|	duplicates the third item down on the stack, onto the top
:over3
"	move.l	8(A6),-(A6)
	;


|	swap - ( x y -- y x )
|	swaps the top two items on the stack
:swap
"	move.l	(A6),D0
"	move.l	4(A6),(A6)
"	move.l	D0,4(A6)
	;


|	drop - ( x -- )
|	drops the top item on the stack
:drop
"	addq.l	#4,A6
	;


|	drop2 - ( x -- )
|	drops the top two items on the stack
:drop2
"	addq.l	#8,A6
	;


|	drop3 - ( x -- )
|	drops the top three items on the stack
:drop3
"	add.l	#12,A6
	;


|	drop4 - ( x -- )
|	drops the top three items on the stack
:drop4
"	add.l	#16,A6
	;


|	drop5 - ( x -- )
|	drops the top three items on the stack
:drop5
"	add.l	#20,A6
	;


|	rot - ( x y z -- z x y )
|	rotates the top 3 levels of the stack
:rot
"	move.l	(A6),D0
"	move.l	4(A6),(A6)
"	move.l	8(A6),4(A6)
"	move.l	D0,8(A6)
	;


|	rot4 - ( x y z a -- a x y z )
|	rotates the top 4 levels of the stack
:rot4
"	move.l	(A6),D0
"	move.l	4(A6),(A6)
"	move.l	8(A6),4(A6)
"	move.l	12(A6),8(A6)
"	move.l	D0,12(A6)
	;


|	unrot - ( x y z -- y z x )
|	rotates the top 3 levels of the stack in the other direction
:unrot
"	move.l	(A6),D0
"	move.l	8(A6),(A6)
"	move.l	4(A6),8(A6)
"	move.l	D0,4(A6)
	;

