|	int6.g - provides miscellaneous functions for irq 6
|	(int6_init, the ISR, int6_release).
|	Greg Alexander - 99/8/6


|	int6_init - ( -- )
|	initialize the keyboard/timer interrupt
:int6_init
	0 KB_ext_flag .at
	0 KB_up_flag .at
	0 KB_shifts .at
	0 KB_ctrls .at				| ... clear out translate flags
	KB_mystery_val KB_mystery_reg .atb	| fix kbd bug?
	0 jiffies .at				| clear jiffies
"	movec.l	VBR,D0				| get VBR
"	move.l	D0,-(A6)
	30*4 .add .dup .bang old_ISR .at	| save old ISR
	ISR .swap .at				| load new ISR
"	clr.l	D0
"	move.w	SR,D0
"	move.l	D0,-(A6)
	.dup old_SR .at				| save old SR
	0xf8ff .andb 0x0500 .orb		| create new value for SR
"	move.l	(A6)+,D0
"	move.w	D0,SR
	;


|	int6_release - ( -- )
|	reverse of int6_init -- restores all interrupts/status.
:int6_release
	,old_SR
"	move.l	(A6)+,D0
"	move.w	D0,SR				| restore SR
	,old_ISR
"	movec.l	VBR,D0				| get VBR
"	move.l	D0,-(A6)
	30*4 .add >at				| restore ISR
	

|	variables to save those things
?old_ISR
?old_SR


|	ISR - ( -- )
|	the keyboard/timer ISR, called whenever there is a level 6
|	autovectored interrupt after int6_init -- should never be called
|	by usercode
|	because we are all about caller saves, and we weren't called by
|	a caller who is aware of this, we really need to save D0-D7/A0-A5
'ISR
"	movem.l	D0-D7/A0-A5,-(A6) | save all regs except stacks
"	btst.b	#7,KB_status_reg | check if it's really a kbd int
"	beq	ISR_timer	| if it isn't, try timer
	KB_data_reg .bangb	| grab data from kbd
	.translate .dup -1 .eq drop enqueue .ifte
'ISR_exit
"	movem.l	(A6)+,D0-D7/A0-A5
"	clr.b	INT_pending
"	rte

'ISR_timer			| called if the kbd didn't do it
"	btst.b	#5,INT_pending	| test if the timer generated this one
"	beq	ISR_exit	| if not, consider it spurious and ignore it
	jiffies .inc >ISR_exit	| have to be careful here not to frob ret stack


/jiffies

|	keyboard constants
"INT_pending	= 0x7f200005
"KB_mystery_reg	= 0x7f200014
"KB_status_reg	= 0x7f200015
"KB_data_reg	= 0x7f200017
"KB_mystery_val	= 0x08


|	translate - ( scan -- ascii )
|	converts one scancode to an ASCII code -- returns -1 if no ASCII
|	code is avaliable yet (i.e., this scancode is a keyup or similar)
'translate	.dup KB_ext .eq tr_ext tr_no_ext >ifte
'tr_ext		.drop 1 KB_ext_flag .at -1 ;
'tr_no_ext	.dup KB_up .eq tr_up tr_noup >ifte
'tr_up		.drop 1 KB_up_flag .at -1 ;
'tr_noup	.dup KB_ctrl .eq tr_ctrl tr_no_ctrl >ifte
'tr_ctrl	.drop KB_lctrl_flag ,KB_ext_flag tr_inc .ift >tr_frob
'tr_inc		0 KB_ext_flag .at 2 >add
'tr_no_ctrl	,KB_ext_flag tr_clrext tr_good1 >ifte
'tr_clrext	0 KB_ext_flag .at .drop -1 ;
'tr_good1	.dup KB_lshift .eq tr_lshift tr_nolshift >ifte
'tr_lshift	.drop KB_lshift_flag >tr_frob
'tr_nolshift	.dup KB_rshift .eq tr_rshift tr_noshift >ifte
'tr_rshift	.drop KB_rshift_flag >tr_frob
'tr_noshift	,KB_up_flag tr_updrop tr_good2 >ifte
'tr_updrop	.drop 0 KB_up_flag .at -1 ;
'tr_good2	4 .times KB_map .add		| compute basic offset
		,KB_ctrls tr_ctrlinc tr_noctrlinc >ifte
'tr_ctrlinc	3 .add >tr_lookup
'tr_noctrlinc	,KB_shifts tr_shiftinc tr_norminc >ifte
'tr_shiftinc	2 .add >tr_lookup
'tr_norminc	1 .add >tr_lookup
'tr_lookup	>bangb

'tr_frob	,KB_up_flag tr_frob_up tr_frob_down .ifte .swap .atw -1 ;
'tr_frob_up	0 KB_up_flag .at 0 ;
'tr_frob_down	1 ;


|	useful scancodes:
"KB_ext		= 0xE0
"KB_up		= 0xF0
"KB_ctrl	= 0x14
"KB_lshift	= 0x12
"KB_rshift	= 0x59

|	keyboard-related flags
?KB_ext_flag
?KB_up_flag
"KB_shifts:
"KB_lshift_flag:.word	0
"KB_rshift_flag:.word	0
"KB_ctrls:
"KB_lctrl_flag:	.word	0
"KB_rctrl_flag:	.word	0

"KB_map		= 0xfffe95b4	| address for ROM-based scancode table
