|	nibbles.g - the main module for nibbles
|	defines the data structures and the elementary functions for
|	nibbles (init_game, set_direction, step_game)
|	when the game ends, whichever function in here detects it will
|	call exit on its own (and bother with int6_release/etc).
|	Greg Alexander - 99/8/6

|	init_game - ( -- )
|	calls next_board and clears the scores
:init_game	0 l_score .at 0 r_score .at	| clear scores
	0 curr_board .at	| clear current board...
	>next_board


|	next_board - ( jiffy -- jiffy )
|	copies in the board indicated by curr_board from the array at
|	boards (board 0 is the current board)
'next_board	curr_board .inc			| increment curr_board
	,curr_board num_boards .gt end_nibbles .ift| detect end-of-game
	,curr_board 1864 .times boards .add	| ( pointer_to_board )
	boards 1864 .memcpy			| copy in board
	9 score_num .at				| set number of scores to go
	0 .xyflush 1 .xyflush			| flush queues
	,l_startx ,l_starty 0 .xyenqueue	| queue left start loc
	1 ,l_startx ,l_starty .atboard		| draw left worm
	,r_startx ,r_starty 1 .xyenqueue	| queue right start loc
	2 ,r_startx ,r_starty .atboard		| draw right worm
	1 l_length .at 1 r_length .at		| initialize lengths
	0 l_dead .at 0 r_dead .at		| both worms alive
|	0 l_dirdone .at 0 r_dirdone .at		| neither worm has turned
	.place_score .redraw_all		| redraw stuff
	.drop ,jiffies 10 >add			| update timer


|	end_nibbles - ( -- )
|	exits gracefully (prints message, restores int6, calls exit)
'end_nibbles	7 34 10 exit_str .print_str	| print message
	.getchar .drop .int6_release >exit


|	set_direction - ( dir player -- )
|	sets direction for worm player (0=left, 1=right) to dir
|	uses atdir to make sure no 180s are performed, and uses dirdone
|	to make sure nobody changes direction twice in one turn
|	dirdone is (temporarily?) removed because I don't like how
|	it feels, even if it allows "cheating"
:set_direction	r_setdir l_setdir .ifte		| ( dir adr doneadr )
|		.dup .bang .swap 1 .swap .at	| ( dir adr flag )
|		drop2 atdir >ifte
		>atdir
'r_setdir	r_dir ;|r_dirdone ;
'l_setdir	l_dir ;|l_dirdone ;
|	atdir - ( dir adr -- )
|	this will set the direction only if the new and old directions
|	do not add up to 3 (meaning they are going in opposite dirs)
'atdir		.dup2 .bang .add 3 .eq drop2 at >ifte


|	redraw_all - ( -- )
|	redraws all of the screen
'redraw_all		.clrscr 0 .redraw_all_helper >redraw_score
'redraw_all_helper	.dup .redraw_row
			1 .add .dup 23 .lt redraw_all_helper drop >ifte


|	redraw_row - ( row -- )
|	redraw that row
'redraw_row		0 >redraw_row_helper
'redraw_row_helper	.dup2 .redraw_cell
			1 .add .dup 80 .lt redraw_row_helper drop2 >ifte


|	redraw_cell - ( row col -- )
|	redraws the cell associated with that location -- uses screen
|	coords, so actually draws two cells from the board
'redraw_cell	.swap .dup2 80 .times .add data .add .bangb	| ( x y cell )
	.dup 0 .eq rc_black .ift
	.dup 1 .eq rc_left .ift
	.dup 2 .eq rc_right .ift
	.dup 3 .eq rc_wall .ift					| ( x y attr )
	.rot 0x20 .rot4 >put_attr_xy
'rc_black	.drop 0x07 ;
'rc_left	.drop 0x67 ;
'rc_right	.drop 0x67 ;
'rc_wall	.drop 0x77 ;


|	redraw_score - ( -- )
|	redraws both the score goal and the current game score
'redraw_score	7 ,score_x ,score_y ,score_val .print_nibble
	7 2 23 left_score_str .print_str
	7 8 23 ,l_score .print_word
	7 66 23 right_score_str .print_str
	7 73 23 ,r_score >print_word


|	place_score - ( -- )
|	places the score item at a random location on the map
'place_score	10 ,score_num .sub score_val .at	| set the value
		,jiffies .dup 0x3e .andb		| random X ...
		.over 0x1f .andb .dup 22 .gt ps_shrink .ift| random Y ...
		.move_score				| now randomize..
		score_y .at score_x .at >drop		| save new location
'ps_shrink	11 >sub


|	move_score - ( jiffies score_x score_y -- )
|	moves the score around on the board until the timer ticks
'move_score	.inc_score .dup2 .bangboard		| ( jiffs sx sy flag )
		move_score move_score2 >ifte
'move_score2	.over3 ,jiffies .eq move_score >ift
'inc_score	.swap 2 .add .dup 80 .eq inc_col swap >ifte
'inc_col	.drop 0 .swap 1 .add .dup 23 .eq inc_corner >ift
'inc_corner	.drop 0 ;


|	step_game - ( jiffy -- jiffy )
|	steps the game one turn (moves worms, checks for worm death, checks
|	for worm score )
|	doesn't itself use jiffy, but next_board will
:step_game	.l_move .r_move		| move and kill left and right
	.l_do_score .r_do_score		| check if they landed on paydirt
|	0 l_dirdone .at 0 r_dirdone .at	| clear their has-turned flags
	,score_num .not ,l_dead ,r_dead .and .or next_board >ift


|	l_move - ( -- )
|	moves the left worm
'l_move ,l_dead .not l_move_help >ift
'l_move_help 0 .xylength ,l_length .eq l_move_tail .ift
	,l_startx ,l_starty .dup2 0 .xyenqueue 		| save old location
	,l_dir .worm_move				| update coordinates
	.dup2 l_starty .at l_startx .at			| save coords
	.dup2 .bangboard l_die do_live >ifte		| live or die
'l_move_tail 0 .xydequeue .dup2 0 .rot .atboard		| clear tail
	.swap >redraw_cell				| draw that change
'l_die	0xffffffff l_dead .at 0x70 13 23 dead_str .print_str >drop2


|	r_move - ( -- )
|	moves the right worm
'r_move ,r_dead .not r_move_help >ift
'r_move_help 1 .xylength ,r_length .eq r_move_tail .ift
	,r_startx ,r_starty .dup2 1 .xyenqueue 		| save old location
	,r_dir .worm_move				| update coordinates
	.dup2 r_starty .at r_startx .at			| save coords
	.dup2 .bangboard r_die do_live >ifte		| live or die
'r_move_tail 1 .xydequeue .dup2 0 .rot .atboard		| clear tail
	.swap >redraw_cell				| draw that change
'r_die	0xffffffff r_dead .at 0x70 60 23 dead_str .print_str >drop2

|	do_live is common to both l_move and r_move:
'do_live	.dup2 1 .rot .atboard .swap >redraw_cell


|	l_do_score - ( -- )
|	checks if the left worm just scored
'l_do_score	,l_startx ,score_x .eq l_score2 >ift
'l_score2	,l_starty ,score_y .eq l_score3 >ift
'l_score3	score_num .dec				| one less score to go
	,l_score ,score_val .add l_score .at		| add in score
	,l_length ,score_val .add l_length .at		| add to length
	,score_num re_score >ift


|	r_do_score - ( -- )
|	checks if the right worm just scored
'r_do_score	,r_startx ,score_x .eq r_score2 >ift
'r_score2	,r_starty ,score_y .eq r_score3 >ift
'r_score3	score_num .dec				| one less score to go
	,r_score ,score_val .add r_score .at		| add in score
	,r_length ,score_val .add r_length .at		| add to length
	,score_num re_score >ift

|	re_score is common to both l_do_score and r_do_score
're_score	.place_score >redraw_score


|	worm_move - ( x y dir -- x y )
|	updates x,y according to dir
'worm_move .dup 0 .eq wm_left .ift
	.dup 1 .eq wm_down .ift
	.dup 2 .eq wm_up .ift
	3 .eq wm_right >ift
'wm_left	.rot .swap 1 .sub .swap .rot >rot
'wm_down	.swap 1 .add >swap
'wm_up		.swap 1 .sub >swap
'wm_right	.swap 1 .add >swap


|	atboard - ( val x y -- )
|	sets the value at x,y to val
'atboard	80 .times .add data .add >atb


|	bangboard - ( x y -- val )
|	gets val from x,y in the board
'bangboard	80 .times .add data .add >bangb


|	strings:
"exit_str:		.ascii "GAME OVER!\0"
"dead_str:		.ascii "DEAD!\0"
"left_score_str:	.ascii "LEFT: \0"
"right_score_str:	.ascii "RIGHT: \0"
".even


|	data structures
?curr_board		| the current board we're playing on
?l_score		| left player's score
?r_score		| ...
?l_length		| left player's length
?r_length
|?l_dirdone		| flag to say if a player's already changed
|?r_dirdone		| direction once this turn
?l_dead			| true if left player died ...
?r_dead
?score_x		| location of the score item
?score_y
?score_val		| value of score item
?score_num		| number of scores to go until next map

|	each board is a structure containing the starting points of each
|	player's worm, and a row-major byte-array of the actual board
|	which is 80x40, with the following values: 0 = empty, 1 =
|	left-player's worm, 2 = right-player's worm, 3 = wall
|	this structure is overall 6*4+80*23=1864 bytes
"num_boards = 6
"boards:
"l_startx:	.long 0
"l_starty:	.long 0
"r_startx:	.long 0
"r_starty:	.long 0
"l_dir:		.long 0
"r_dir:		.long 0
"data:	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 1
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 2
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 3
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 4
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 5
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 6
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 7
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 8
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 9
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 10
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 11
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 12
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 13
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 14
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 15
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 16
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 17
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 18
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 19
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 20
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 21
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0		| row 22

|	BOARD 1
".long 6,11	|l_start
".long 73,11	|r_start
".long 1,2	|l_dir,r_dir
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 0
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 1
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 2
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 3
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 4
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 5
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 6
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 7
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 8
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 9
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 10
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 11
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 12
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 13
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 14
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 15
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 16
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 17
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 18
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 19
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 20
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 21
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 22

|	BOARD 2
".long 40,5	|l_start
".long 40,17	|r_start
".long 0,3	|l_dir,r_dir
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 0
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 1
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 2
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 3
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 4
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 5
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 6
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 7
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 8
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 9
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 10
"	.byte	3,0,0,0,0,0,0,0,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,3		| row 11
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 12
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 13
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 14
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 15
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 16
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 17
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 18
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 19
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 20
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 21
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 22

|	BOARD 3
".long 3,11	|l_start
".long 76,11	|r_start
".long 1,2	|l_dir,r_dir
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 0
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 1
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 2
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 3
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 4
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 5
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 6
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 7
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 8
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 9
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 10
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 11
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 12
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 13
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 14
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 15
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 16
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 17
"	.byte	3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3		| row 18
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 19
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 20
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 21
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 22

|	BOARD 4
".long 40,10	|l_start
".long 40,12	|r_start
".long 0,3	|l_dir,r_dir
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 0
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 1
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 2
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 3
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 4
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 5
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 6
"	.byte	3,0,0,0,0,0,0,0,0,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,3		| row 7
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 8
"	.byte	3,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,3		| row 9
"	.byte	3,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,3		| row 10
"	.byte	3,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,3		| row 11
"	.byte	3,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,3		| row 12
"	.byte	3,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,3		| row 13
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 14
"	.byte	3,0,0,0,0,0,0,0,0,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,3		| row 15
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 16
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 17
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 18
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 19
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 20
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 21
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 22

|	BOARD 5
".long 3,5	|l_start
".long 76,5	|r_start
".long 3,0	|l_dir,r_dir
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 0
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 1
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 2
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 3
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 4
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 5
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 6
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 7
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 8
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 9
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 10
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,0,0,0,0,0,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 11
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 12
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 13
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 14
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 15
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 16
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 17
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 18
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 19
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 20
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 21
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 22

|	BOARD 6
".long 3,19	|l_start
".long 76,19	|r_start
".long 2,2	|l_dir,r_dir
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 0
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 1
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 2
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 3
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 4
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 5
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 6
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 7
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 8
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 9
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 10
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 11
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 12
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 13
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 14
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 15
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 16
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 17
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 18
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 19
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 20
"	.byte	3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
"	.byte	0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3		| row 21
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3
"	.byte	3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3		| row 22
