|	xyqueue.g - handles the circular queues for the worms ...
|	Greg Alexander - 99/8/11
|	Provides four functions, xyenqueue to add to the tail of the
|	queue, xydequeue to take something off of the head, and xylength
|	to measure the number of entries in the queue, and xyflush to
|	flush a queue.  The first interesting entry to read is head+1
|	and new characters are written at tail+1.


|	xyenqueue - ( x y player -- )
|	adds an x,y coord pair to the queue
|	on queue overflow, it silently discards the coords
|	player is 0 for left, 1 for right
:xyenqueue l_queue r_queue .ifte		| ( x y q hptr tptr )
	.dup .bang 1 .add 0xff .andb		| ( x y q hptr tptr newtail )
	.unrot .over .eq			| ( x y q tp nt flag )
	drop5 xyenqueue_add >ifte		| ( x y q tp nt )
'xyenqueue_add .dup .unrot .at			| ( x y q nt )
	8 .times .add				| ( x y adr )
	.dup 4 .add .rot .at >at		| ( )
	
'l_queue lxyqueue l_head l_tail ;
'r_queue rxyqueue r_head r_tail ;


|	xydequeue - ( player -- x y )
|	If there is a pair to be read, it returns it
|	otherwise pushes 0 0
:xydequeue l_queue r_queue .ifte		| ( q hptr tptr )
	.over .bang .over .bang			| ( q hptr tptr head tail )
	.eq xydeq_uf xydeq_get >ifte		| ( q hptr tptr )
'xydeq_uf .drop3 0 0 ;
'xydeq_get .drop .dup .bang 1 .add 0xff .andb	| ( q hptr newhead )
	.dup .unrot .at				| ( q newhead )
	8 .times .add				| ( adr )
	.dup .bang .swap 4 .add .bang >swap	| ( x y )


|	xylength - ( player -- length )
|	tells you how many entries are in the queue associated with that
|	player
:xylength l_queue r_queue .ifte .unrot .drop	| ( hptr tptr )
	.bang .swap .bang			| ( tail head )
	.dup2 .gt xyl_case1 xyl_case2 >ifte	| ( tail head )
'xyl_case1 >sub					| tail > head, so tail-head
'xyl_case2 .dup2 .eq xyl_case3 xyl_case4 >ifte	| ( tail head )
'xyl_case3 0 ;					| tail == head, so 0
'xyl_case4 .swap 256 .add .swap >sub		| tail < head, so tail+256-head


|	xyflush - ( player -- )
|	flushes the associated queue
:xyflush l_queue r_queue .ifte .unrot .drop	| ( q hptr tptr )
	0 .swap .at 0 .swap >at

|	variables:
"lxyqueue:	.=.+ 256*8 | if you change the size, you'll need to
"			| change the way that wrap-over is implemented
"rxyqueue:	.=.+ 256*8 | if you change the size, you'll need to
"			| change the way that wrap-over is implemented
?l_head
?l_tail
?r_head
?r_tail
